@@ -5,7 +5,7 @@ import re
 from lxml import etree
 
 from zeep.exceptions import XMLParseError
-from zeep.loader import absolute_location, load_external
+from zeep.loader import absolute_location, load_external, normalize_location
 from zeep.utils import as_qname, qname_attr
 from zeep.xsd import elements as xsd_elements
 from zeep.xsd import types as xsd_types
@@ -185,6 +185,8 @@ class SchemaVisitor(object):
         if not namespace and not location:
             self.document._has_empty_import = True
 
+        location = normalize_location(self.schema.settings, location, self.document._location)
+
         # Check if the schema is already imported before based on the
         # namespace. Schema's without namespace are registered as 'None'
         document = self.schema.documents.get_by_namespace_and_location(namespace, location)
@@ -209,7 +211,8 @@ class SchemaVisitor(object):
         # Load the XML
         schema_node = load_external(
             location,
-            self.schema._transport,
+            transport=self.schema._transport,
+            base_url=self.document._location,
             settings=self.schema.settings)
 
         # Check if the xsd:import namespace matches the targetNamespace. If
@@ -425,7 +428,7 @@ class SchemaVisitor(object):
         # Check of wsdl:arayType
         array_type = node.get('{http://schemas.xmlsoap.org/wsdl/}arrayType')
         if array_type:
-            match = re.match('([^\[]+)', array_type)
+            match = re.match(r'([^\[]+)', array_type)
             if match:
                 array_type = match.groups()[0]
                 qname = as_qname(array_type, node.nsmap)
